internal

package
v1.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInputOutputLengthMismatch = errors.New("input files and output files have different length")
	ErrMissingInputDir           = errors.New(
		"input directory is required when using the output directory",
	)
	ErrMissingOutputDir = errors.New(
		"output directory is required when using the input directory",
	)
)

Functions

func Main

func Main()

Types

type Config

type Config struct {
	InputDir    string
	OutputDir   string
	InputFiles  flagStringArray
	OutputFiles flagStringArray
	Excludes    flagStringArray
	Contexts    flagStringArray
}

func ParseFlags

func ParseFlags() *Config

func (*Config) ApplyDefaults

func (r *Config) ApplyDefaults()

func (*Config) Validate

func (r *Config) Validate() error

Jump to